clear all

cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder"
use mortality_rate_JHR.dta

*********
* setup *
*********


gen int day1=bday if bday<=182
replace day1=bday-365 if bday>182
gen byte after=(month1>0)

gen int disc=.
replace disc=41 if (byear==1941 & after==0) | (byear==1942 & after==1) 
replace disc=42 if (byear==1942 & after==0) | (byear==1943 & after==1) 
replace disc=43 if (byear==1943 & after==0) | (byear==1944 & after==1) 
replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 
replace disc=55 if (byear==1955 & after==0) | (byear==1956 & after==1)

**** discontinuity *****
forvalues disc=44/54 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}

gen byte treatment=.
replace treatment=1 if (disc>=44 & disc<=49)
replace treatment=0 if (disc>=50 & disc<=52)
drop disc_44

gen byte after_treatment=after*treatment
gen byte control=1-treatment

***** day trends

gen day1_after=day1*after
gen day1_treatment=day1*treatment
gen day1_treatment_after=day1*treatment*after




**** define day
gen day=byear*1000+bday




****************** trends and controls *****************


gen wij=.
global trend "day1" 
global controls1 ""
global restrict1 1
global restrict2 1





******************************************************** Figure 4: Mortality Rate **********************************************************


***************************************************** day of birth *****************************************************

******************** treatment group ******************

preserve

********************
keep if treatment==1
********************

*** generate binned categories

global step "1"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse mort_rate  (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen mort_rate_donut7=mort_rate if day1_cat<=6 & day1_cat>=-7
gen mort_rate_donut14=mort_rate if (day1_cat>=6 & day1_cat<=13) | (day1_cat>=-14 & day1_cat<=-7)
gen mort_rate_nodonut=mort_rate if day1_cat>=14 | day1_cat<=-15


reg mort_rate $trend if day1<0, robust
predict mort_rateY_A if e(sample)
reg mort_rate $trend if day1>=0, robust
predict mort_rateY_B if e(sample)



reg mort_rate $trend if day1<-7, robust
predict mort_rateY_A_donut7 if e(sample)
reg mort_rate $trend if day1>=7, robust
predict mort_rateY_B_donut7 if e(sample)




#delimit;

scatter mort_rate_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter mort_rate_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter mort_rate_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line mort_rateY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line mort_rateY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-180 0 180)
 xscale(range(-180 0 180))
 ylabel(.2 .4)
 title(Panel A: Treatment, position(11) size(medsmall))
 ytitle(Mortality Rate, size(small))
 xtitle(day of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("mort_rate_treat_day",replace);





#delimit cr;


******************** control group ******************

restore
preserve

********************
keep if treatment==0
********************


*** generate binned categories

global step "1"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step

collapse mort_rate (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen mort_rate_donut7=mort_rate if day1_cat<=6 & day1_cat>=-7
gen mort_rate_donut14=mort_rate if (day1_cat>=6 & day1_cat<=13) | (day1_cat>=-14 & day1_cat<=-7)
gen mort_rate_nodonut=mort_rate if day1_cat>=14 | day1_cat<=-15


reg mort_rate $trend if day1<0, robust
predict mort_rateY_A if e(sample)
reg mort_rate $trend if day1>=0, robust
predict mort_rateY_B if e(sample)



reg mort_rate $trend if day1<-7, robust
predict mort_rateY_A_donut7 if e(sample)
reg mort_rate $trend if day1>=7, robust
predict mort_rateY_B_donut7 if e(sample)




#delimit;

scatter mort_rate_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter mort_rate_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter mort_rate_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line mort_rateY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line mort_rateY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-180 0 180)
 xscale(range(-180 0 180))
 ylabel(.1 .3)
 title(Panel C: Control, position(11) size(medsmall))
 ytitle(Mortality Rate, size(small))
 xtitle(day of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("mort_rate_controls_day",replace);



#delimit cr;


******************** treatment-control differences ******************

restore
preserve

drop if treatment==.

collapse mort_rate , by(day1 treatment)
gen int id=_n
reshape wide mort_rate , i(id) j(treatment)
collapse mort_rate1  mort_rate0  , by(day1)
gen mort_rate=mort_rate1-mort_rate0


gen day2=day1*day1
gen day3=day1*day1*day1


*** generate binned categories

global step "1"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step

collapse mort_rate  (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


reg mort_rate $trend if day1<0, robust
predict mort_rateY_A if e(sample)
reg mort_rate $trend if day1>=0, robust
predict mort_rateY_B if e(sample)




reg mort_rate $trend if day1<-7, robust
predict mort_rateY_A_donut7 if e(sample)
reg mort_rate $trend if day1>=7, robust
predict mort_rateY_B_donut7 if e(sample)





gen mort_rate_donut7=mort_rate if day1_cat<=6 & day1_cat>=-7
gen mort_rate_donut14=mort_rate if (day1_cat>=6 & day1_cat<=13) | (day1_cat>=-14 & day1_cat<=-7)
gen mort_rate_nodonut=mort_rate if day1_cat>=14 | day1_cat<=-15




#delimit;

scatter mort_rate_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter mort_rate_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter mort_rate_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line mort_rateY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line mort_rateY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-180 0 180)
 xscale(range(-180 0 180))
 ylabel(-.1 .2)
 title(Panel E: Treatment-Control, position(11) size(medsmall))
 ytitle(Mortality Rate, size(small))
 xtitle(day of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("mort_rate_diff_day",replace);



#delimit cr;

***************************************************** week of birth *****************************************************

restore
preserve

******************** treatment group ******************

********************
keep if treatment==1
********************

*** generate predicted values for fitted lines

reg mort_rate $trend if day1<0, robust
predict mort_rateY_A if e(sample)
reg mort_rate $trend if day1>=0, robust
predict mort_rateY_B if e(sample)


reg mort_rate $trend if day1<-7, robust
predict mort_rateY_A_donut7 if e(sample)
reg mort_rate $trend if day1>=7, robust
predict mort_rateY_B_donut7 if e(sample)



*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse mort_rate mort_rateY_A mort_rateY_B  mort_rateY_A_donut7 mort_rateY_B_donut7  (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)



gen mort_rate_donut7=mort_rate if day1_cat==-1 | day1_cat==0
gen mort_rate_donut14=mort_rate if day1_cat==-2 | day1_cat==1
gen mort_rate_nodonut=mort_rate if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter mort_rate_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter mort_rate_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter mort_rate_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line mort_rateY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line mort_rateY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(0.2 .4)
 title(Panel B: Treatment, position(11) size(medsmall))
 ytitle(Mortality Rate, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("mort_rate_treat_week",replace);





#delimit cr;


******************** control group ******************

restore
preserve

********************
keep if treatment==0
********************

reg mort_rate $trend if day1<0, robust
predict mort_rateY_A if e(sample)
reg mort_rate $trend if day1>=0, robust
predict mort_rateY_B if e(sample)


reg mort_rate $trend if day1<-7, robust
predict mort_rateY_A_donut7 if e(sample)
reg mort_rate $trend if day1>=7, robust
predict mort_rateY_B_donut7 if e(sample)



*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse mort_rate mort_rateY_A mort_rateY_B  mort_rateY_A_donut7 mort_rateY_B_donut7  (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen mort_rate_donut7=mort_rate if day1_cat==-1 | day1_cat==0
gen mort_rate_donut14=mort_rate if day1_cat==-2 | day1_cat==1
gen mort_rate_nodonut=mort_rate if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter mort_rate_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter mort_rate_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter mort_rate_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line mort_rateY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line mort_rateY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(.1 .3)
 title(Panel D: Control, position(11) size(medsmall))
 ytitle(Mortality Rate, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("mort_rate_controls_week",replace);


#delimit cr;


******************** treatment-control differences ******************

restore
preserve

drop if treatment==.

*collapse mort_rate employed density (count) mort_rate_c=mort_rate (count) employed_c=employed (count) density_c=density, by(day1 treatment)
collapse mort_rate , by(day1 treatment)
gen int id=_n
reshape wide mort_rate , i(id) j(treatment)
collapse mort_rate1  mort_rate0 , by(day1)
gen mort_rate=mort_rate1-mort_rate0



gen day2=day1*day1
gen day3=day1*day1*day1

reg mort_rate $trend if day1<0, robust
predict mort_rateY_A if e(sample)
reg mort_rate $trend if day1>=0, robust
predict mort_rateY_B if e(sample)



reg mort_rate $trend if day1<-7, robust
predict mort_rateY_A_donut7 if e(sample)
reg mort_rate $trend if day1>=7, robust
predict mort_rateY_B_donut7 if e(sample)




*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse mort_rate mort_rateY_A mort_rateY_B  mort_rateY_A_donut7 mort_rateY_B_donut7   (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen mort_rate_donut7=mort_rate if day1_cat==-1 | day1_cat==0
gen mort_rate_donut14=mort_rate if day1_cat==-2 | day1_cat==1
gen mort_rate_nodonut=mort_rate if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter mort_rate_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter mort_rate_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter mort_rate_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line mort_rateY_A day1_cat,
 clcolor(gs10)
 clwidth(thick)
 clpattern(solid)
 || line mort_rateY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-.1 .2)
 title(Panel F: Treatment-Control, position(11) size(medsmall))
 ytitle(Mortality Rate, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("mort_rate_diff_week",replace);


#delimit cr;



graph combine mort_rate_treat_day.gph mort_rate_treat_week.gph mort_rate_controls_day.gph mort_rate_controls_week.gph mort_rate_diff_day.gph mort_rate_diff_week.gph, ysize(9) holes(3 6 9) scheme(s1color) saving("Figure4",replace)

erase mort_rate_treat_week.gph
erase mort_rate_controls_week.gph
erase mort_rate_diff_week.gph


erase mort_rate_treat_day.gph
erase mort_rate_controls_day.gph
erase mort_rate_diff_day.gph


