
clear all

cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder"
use mortality_rate_by_cause_death.dta

*********
* Cancer *
*********

keep if cancer==1

*********
* setup *
*********

gen int day1=bday if bday<=182
replace day1=bday-365 if bday>182
gen byte after=(month1>0)


gen int disc=.
replace disc=41 if (byear==1941 & after==0) | (byear==1942 & after==1) 
replace disc=42 if (byear==1942 & after==0) | (byear==1943 & after==1) 
replace disc=43 if (byear==1943 & after==0) | (byear==1944 & after==1) 
replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 
replace disc=55 if (byear==1955 & after==0) | (byear==1956 & after==1)


gen byte treatment=.
replace treatment=1 if (disc>=44 & disc<=49)
replace treatment=0 if (disc>=50 & disc<=52)


gen byte after_treatment=after*treatment
gen byte control=1-treatment

***** day trends
gen day1_after=day1*after
gen day1_treatment=day1*treatment
gen day1_treatment_after=day1*treatment*after


**** discontinuity *****
forvalues disc=44/54 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}
drop disc_44

**** define day
gen day=byear*1000+bday


************************************ main restrictions *****************************************

gen wij=.
global trend "day1" 
global controls1 ""
global restrict1 1
global restrict2 1


***************************************************** week of birth *****************************************************

drop if treatment==.

*collapse mort_rate employed density (count) mort_rate_c=mort_rate (count) employed_c=employed (count) density_c=density, by(day1 treatment)
collapse mort_rate , by(day1 treatment)
gen int id=_n
reshape wide mort_rate , i(id) j(treatment)
collapse mort_rate1  mort_rate0 , by(day1)
gen mort_rate=mort_rate1-mort_rate0



gen day2=day1*day1
gen day3=day1*day1*day1

reg mort_rate $trend if day1<0, robust
predict mort_rateY_A if e(sample)
reg mort_rate $trend if day1>=0, robust
predict mort_rateY_B if e(sample)

reg mort_rate $trend if day1<-7, robust
predict mort_rateY_A_donut7 if e(sample)
reg mort_rate $trend if day1>=7, robust
predict mort_rateY_B_donut7 if e(sample)

*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse mort_rate mort_rateY_A mort_rateY_B  mort_rateY_A_donut7 mort_rateY_B_donut7   (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen mort_rate_donut7=mort_rate if day1_cat==-1 | day1_cat==0
gen mort_rate_donut14=mort_rate if day1_cat==-2 | day1_cat==1
gen mort_rate_nodonut=mort_rate if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter mort_rate_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter mort_rate_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter mort_rate_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line mort_rateY_A day1_cat,
 clcolor(gs10)
 clwidth(thick)
 clpattern(solid)
 || line mort_rateY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-.05 .1)
 title(Panel C: Cancer, position(11) size(medsmall))
 ytitle(Mortality Rate, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("cancer_week",replace);

#delimit cr;



clear all

cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder"
use mortality_rate_by_cause_death.dta

*********
* Circulatory *
*********

keep if circulatory==1
*********
* setup *
*********

gen int day1=bday if bday<=182
replace day1=bday-365 if bday>182
gen byte after=(month1>0)

gen int disc=.

replace disc=41 if (byear==1941 & after==0) | (byear==1942 & after==1) 
replace disc=42 if (byear==1942 & after==0) | (byear==1943 & after==1) 
replace disc=43 if (byear==1943 & after==0) | (byear==1944 & after==1) 
replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 
replace disc=55 if (byear==1955 & after==0) | (byear==1956 & after==1)


gen byte treatment=.
replace treatment=1 if (disc>=44 & disc<=49)
replace treatment=0 if (disc>=50 & disc<=52)


gen byte after_treatment=after*treatment
gen byte control=1-treatment

***** day trends
gen day1_after=day1*after
gen day1_treatment=day1*treatment
gen day1_treatment_after=day1*treatment*after


**** discontinuity *****
forvalues disc=44/54 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}
drop disc_44

**** define day
gen day=byear*1000+bday


************************************ main restrictions *****************************************

gen wij=.
global trend "day1" 
global controls1 ""
global restrict1 1
global restrict2 1



***************************************************** week of birth *****************************************************

******************** treatment-control differences ******************



drop if treatment==.

*collapse mort_rate employed density (count) mort_rate_c=mort_rate (count) employed_c=employed (count) density_c=density, by(day1 treatment)
collapse mort_rate , by(day1 treatment)
gen int id=_n
reshape wide mort_rate , i(id) j(treatment)
collapse mort_rate1  mort_rate0 , by(day1)
gen mort_rate=mort_rate1-mort_rate0



gen day2=day1*day1
gen day3=day1*day1*day1

reg mort_rate $trend if day1<0, robust
predict mort_rateY_A if e(sample)
reg mort_rate $trend if day1>=0, robust
predict mort_rateY_B if e(sample)

reg mort_rate $trend if day1<-7, robust
predict mort_rateY_A_donut7 if e(sample)
reg mort_rate $trend if day1>=7, robust
predict mort_rateY_B_donut7 if e(sample)

*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse mort_rate mort_rateY_A mort_rateY_B  mort_rateY_A_donut7 mort_rateY_B_donut7   (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)

gen mort_rate_donut7=mort_rate if day1_cat==-1 | day1_cat==0
gen mort_rate_donut14=mort_rate if day1_cat==-2 | day1_cat==1
gen mort_rate_nodonut=mort_rate if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter mort_rate_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter mort_rate_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter mort_rate_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line mort_rateY_A day1_cat,
 clcolor(gs10)
 clwidth(thick)
 clpattern(solid)
 || line mort_rateY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-.05 .1)
 title(Panel D: Circulatory, position(11) size(medsmall))
 ytitle(Mortality Rate, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("circulatory_week",replace);

#delimit cr;



clear all

cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder"
use mortality_rate_by_cause_death.dta

*********
* Preventable *
*********

keep if preventable_external==1
*********
* setup *
*********


gen int day1=bday if bday<=182
replace day1=bday-365 if bday>182
gen byte after=(month1>0)

gen int disc=.

replace disc=41 if (byear==1941 & after==0) | (byear==1942 & after==1) 
replace disc=42 if (byear==1942 & after==0) | (byear==1943 & after==1) 
replace disc=43 if (byear==1943 & after==0) | (byear==1944 & after==1) 
replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 
replace disc=55 if (byear==1955 & after==0) | (byear==1956 & after==1)


 
**** Core years (no transition year):
**** treatment years: 1944-1945, 1945-1946, 1946-1947, 1947-1948, 1948-1949, 1949-1950
**** control years: 1950-1951, 1951-1952, 1952-1953

gen byte treatment=.
replace treatment=1 if (disc>=44 & disc<=49)
replace treatment=0 if (disc>=50 & disc<=52)


gen byte after_treatment=after*treatment
gen byte control=1-treatment

***** day trends
gen day1_after=day1*after
gen day1_treatment=day1*treatment
gen day1_treatment_after=day1*treatment*after


**** discontinuity *****
forvalues disc=44/54 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}
drop disc_44

**** define day
gen day=byear*1000+bday


************************************ main restrictions *****************************************

gen wij=.
global trend "day1" 
global controls1 ""
global restrict1 1
global restrict2 1

***************************************************** week of birth *****************************************************

******************** treatment-control differences ******************


drop if treatment==.

collapse mort_rate , by(day1 treatment)
gen int id=_n
reshape wide mort_rate , i(id) j(treatment)
collapse mort_rate1  mort_rate0 , by(day1)
gen mort_rate=mort_rate1-mort_rate0



gen day2=day1*day1
gen day3=day1*day1*day1

reg mort_rate $trend if day1<0, robust
predict mort_rateY_A if e(sample)
reg mort_rate $trend if day1>=0, robust
predict mort_rateY_B if e(sample)

reg mort_rate $trend if day1<-7, robust
predict mort_rateY_A_donut7 if e(sample)
reg mort_rate $trend if day1>=7, robust
predict mort_rateY_B_donut7 if e(sample)

*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse mort_rate mort_rateY_A mort_rateY_B  mort_rateY_A_donut7 mort_rateY_B_donut7   (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen mort_rate_donut7=mort_rate if day1_cat==-1 | day1_cat==0
gen mort_rate_donut14=mort_rate if day1_cat==-2 | day1_cat==1
gen mort_rate_nodonut=mort_rate if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter mort_rate_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter mort_rate_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter mort_rate_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line mort_rateY_A day1_cat,
 clcolor(gs10)
 clwidth(thick)
 clpattern(solid)
 || line mort_rateY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-.05 .1)
 title(Panel E: Preventable, position(11) size(medsmall))
 ytitle(Mortality Rate, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("preventable_week",replace);

#delimit cr;



clear all

cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder"
use mortality_rate_by_cause_death.dta


*********
* Treatable *
*********

keep if treatable==1

*********
* setup *
*********

gen int day1=bday if bday<=182
replace day1=bday-365 if bday>182
gen byte after=(month1>0)

gen int disc=.

replace disc=41 if (byear==1941 & after==0) | (byear==1942 & after==1) 
replace disc=42 if (byear==1942 & after==0) | (byear==1943 & after==1) 
replace disc=43 if (byear==1943 & after==0) | (byear==1944 & after==1) 
replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 
replace disc=55 if (byear==1955 & after==0) | (byear==1956 & after==1)

gen byte treatment=.
replace treatment=1 if (disc>=44 & disc<=49)
replace treatment=0 if (disc>=50 & disc<=52)


gen byte after_treatment=after*treatment
gen byte control=1-treatment

***** day trends
gen day1_after=day1*after
gen day1_treatment=day1*treatment
gen day1_treatment_after=day1*treatment*after


**** discontinuity *****
forvalues disc=44/54 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}
drop disc_44

**** define day
gen day=byear*1000+bday


************************************ main restrictions *****************************************


gen wij=.
global trend "day1" 
global controls1 ""
global restrict1 1
global restrict2 1


***************************************************** week of birth *****************************************************

******************** treatment-control differences ******************


drop if treatment==.

*collapse mort_rate employed density (count) mort_rate_c=mort_rate (count) employed_c=employed (count) density_c=density, by(day1 treatment)
collapse mort_rate , by(day1 treatment)
gen int id=_n
reshape wide mort_rate , i(id) j(treatment)
collapse mort_rate1  mort_rate0 , by(day1)
gen mort_rate=mort_rate1-mort_rate0



gen day2=day1*day1
gen day3=day1*day1*day1

reg mort_rate $trend if day1<0, robust
predict mort_rateY_A if e(sample)
reg mort_rate $trend if day1>=0, robust
predict mort_rateY_B if e(sample)



reg mort_rate $trend if day1<-7, robust
predict mort_rateY_A_donut7 if e(sample)
reg mort_rate $trend if day1>=7, robust
predict mort_rateY_B_donut7 if e(sample)


*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse mort_rate mort_rateY_A mort_rateY_B  mort_rateY_A_donut7 mort_rateY_B_donut7   (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen mort_rate_donut7=mort_rate if day1_cat==-1 | day1_cat==0
gen mort_rate_donut14=mort_rate if day1_cat==-2 | day1_cat==1
gen mort_rate_nodonut=mort_rate if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter mort_rate_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter mort_rate_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter mort_rate_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line mort_rateY_A day1_cat,
 clcolor(gs10)
 clwidth(thick)
 clpattern(solid)
 || line mort_rateY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(medium)
 clpattern(solid)
 || line mort_rateY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-.05 .1)
 title(Panel F: Treatable, position(11) size(medsmall))
 ytitle(Mortality Rate, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("treatable_week",replace);
#delimit cr;



graph combine  hosp_time_week.gph health_week.gph cancer_week.gph circulatory_week.gph preventable_week.gph treatable_week.gph, ysize(9) holes(3 6 9) scheme(s1color)  saving("AppendixFigure5",replace)





