clear all

cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder"

use short_census11_internal_migration.dta


*********
* setup *
*********

**** Core years (no transition year):
**** treatment years: 1944-1945, 1945-1946, 1946-1947, 1947-1948, 1948-1949, 1949-1950
**** control years: 1950-1951, 1951-1952, 1952-1953, 1953-1954, 1954-1955


*************
* pre-setup *
*************
collapse (mean) aa-month female-sample  , by (byear bmonth bday)


drop bmonth bday
*leap*
gen byte leap=((mod(byear,4) == 0 & mod(byear,100) != 0) | mod(byear,400) == 0)
gen bmonth=ll
gen bdate=zz

*drop 31st date of months with 30 days
drop if bmonth==4 & bdate==31
drop if bmonth==6 & bdate==31
drop if bmonth==9 & bdate==31
drop if bmonth==11 & bdate==31
drop if bmonth==2 & (bdate==30 | bdate==31) 
drop if bmonth==2 & leap==0 & bdate==29

*keep actual month and day of birth*
quietly gen int bday=.
quietly replace bday=0+bdate if bmonth==1 & leap==1
quietly replace bday=31+bdate if bmonth==2 & leap==1
quietly replace bday=60+bdate if bmonth==3 & leap==1
quietly replace bday=91+bdate if bmonth==4 & leap==1
quietly replace bday=121+bdate if bmonth==5 & leap==1
quietly replace bday=152+bdate if bmonth==6 & leap==1
quietly replace bday=182+bdate if bmonth==7 & leap==1
quietly replace bday=213+bdate if bmonth==8 & leap==1
quietly replace bday=244+bdate if bmonth==9 & leap==1
quietly replace bday=274+bdate if bmonth==10 & leap==1
quietly replace bday=305+bdate if bmonth==11 & leap==1
quietly replace bday=335+bdate if bmonth==12 & leap==1

quietly replace bday=0+bdate if bmonth==1 & leap==0
quietly replace bday=31+bdate if bmonth==2 & leap==0
quietly replace bday=59+bdate if bmonth==3 & leap==0
quietly replace bday=90+bdate if bmonth==4 & leap==0
quietly replace bday=120+bdate if bmonth==5 & leap==0
quietly replace bday=151+bdate if bmonth==6 & leap==0
quietly replace bday=181+bdate if bmonth==7 & leap==0
quietly replace bday=212+bdate if bmonth==8 & leap==0
quietly replace bday=243+bdate if bmonth==9 & leap==0
quietly replace bday=273+bdate if bmonth==10 & leap==0
quietly replace bday=304+bdate if bmonth==11 & leap==0
quietly replace bday=334+bdate if bmonth==12 & leap==0

drop if bday==.
drop if bmonth==.
drop if byear==.



gen int day1=bday if bday<=180
*replace day1=bday-365 if bday>185 
replace day1=bday-365 if bday>185 & leap==0
replace day1=bday-366 if bday>186 & leap==1

**** define day
gen day=byear*1000+bday

**** redfine day1 so cutoff is at 0 (not 1)
replace day1=day1-1

**** define after
gen byte after=(day1>=0)


gen int month1=bmonth if bmonth<=6
replace month1=bmonth-12 if bmonth>6


gen int disc=.

replace disc=41 if (byear==1941 & after==0) | (byear==1942 & after==1) 
replace disc=42 if (byear==1942 & after==0) | (byear==1943 & after==1) 
replace disc=43 if (byear==1943 & after==0) | (byear==1944 & after==1) 
replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 
replace disc=55 if (byear==1955 & after==0) | (byear==1956 & after==1)


 
**** Core years (no transition year):
**** treatment years: 1944-1945, 1945-1946, 1946-1947, 1947-1948, 1948-1949, 1949-1950
**** control years: 1950-1951, 1951-1952, 1952-1953

gen byte treatment=.
replace treatment=1 if (disc>=44 & disc<=49)
replace treatment=0 if (disc>=50 & disc<=52)

gen byte after_treatment=after*treatment
gen byte control=1-treatment

***** day trends
gen day2=day1*day1
gen day3=day1*day1*day1
gen day1_after=day1*after
gen day2_after=day2*after
gen day3_after=day3*after

gen day1_treatment=day1*treatment
gen day2_treatment=day2*treatment
gen day3_treatment=day3*treatment

gen day1_treatment_after=day1*treatment*after
gen day2_treatment_after=day2*treatment*after
gen day3_treatment_after=day3*treatment*after


**** ethnicity ***
forvalues ethnic=1/4 {
   quietly gen byte ethnic_`ethnic'=0 if ethnic!=.
   quietly replace ethnic_`ethnic'=1 if ethnic==`ethnic'
}

**** religion ***
forvalues relig=1/6 {
   quietly gen byte relig_`relig'=0 if relig!=.
   quietly replace relig_`relig'=1 if relig==`relig'
}

**** region of birth *****
forvalues region=1/42 {
   quietly gen byte region_`region'=0 if region!=.
   quietly replace region_`region'=1 if region==`region'
}

**** discontinuity *****
forvalues disc=41/55 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}



*** define any children
replace children=. if female==0
gen byte anychild=(children>0) if children>=0 & children!=.



************************************ main restrictions *****************************************



*************************
**** summary stats for table 1 ****
*************************

sum int_migration if  $restrict2


*************************
**** int_migration ****
*************************


****************************************** regression specifications ************************************************

*create weight variable
gen wij=.


*******************
* define controls *
*******************

global controls1 ""



******************************
* set  bandwidths *
******************************

global bandwidths "180"

**************************
* specify relevant discs *
**************************

global disc "disc_44 disc_45 disc_46 disc_47 disc_48 disc_49 disc_50 disc_51 disc_52 disc_53"

*specify trend and after
global trend "day1 day1_after day1_treatment day1_treatment_after" 
global after="after after_treatment"


*************************************************** Table 4 ***************************************************

*set AppTable 6 outcomes
global outcomes "int_migration" 

*set AppTable 6 file name
global file "AppTable6_int_migation" 

*create outreg file
xi: reg int_migration, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace

preserve

****************************
*** Panel A: full sample ***
****************************

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

****************************
*** Panel B: 7-day donut ***
****************************

drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}


*****************************
*** Panel C: 14-day donut ***
*****************************

drop if (day1>=-14 & day1<=-1) | (day1>=0 & day1<=13) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

restore

erase "$file.txt"

