clear all

cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder"
use mortality_rate_JHR.dta


*************
* pre-setup *
*************

gen byte leap=((mod(byear,4) == 0 & mod(byear,100) != 0) | mod(byear,400) == 0)

gen int day1=bday if bday<=180
replace day1=bday-365 if bday>185 & leap==0
replace day1=bday-366 if bday>186 & leap==1

**** define day
gen day=byear*1000+bday

**** redfine day1 so cutoff is at 0 (not 1)
replace day1=day1-1

**** define after
gen byte after=(day1>=0)


****************************************** setup ************************************************


************************************
* define treatment discontinuities *
************************************



gen int disc=.

replace disc=41 if (byear==1941 & after==0) | (byear==1942 & after==1) 
replace disc=42 if (byear==1942 & after==0) | (byear==1943 & after==1) 
replace disc=43 if (byear==1943 & after==0) | (byear==1944 & after==1) 
replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 
replace disc=55 if (byear==1955 & after==0) | (byear==1956 & after==1)



gen group=1

sort disc day1
append  using collapsed_years_schooling.dta
replace group=2 if group==.
keep if day1<=180

replace after=(day1>=0) if after==.




gen byte treatment=.

*main treatment years
replace treatment=1 if (disc>=44 & disc<=49)

*old control years
replace treatment=0 if (disc>=50 & disc<=52)

*define after*treatment 
gen byte after_treatment=after*treatment

*define separate indicator for control years
gen byte control=1-treatment




*************************************************
*****keep treatment and control cohorts only*****
*************************************************



***** day trends

gen day1_after=day1*after
gen day1_treatment=day1*treatment
gen day1_treatment_after=day1*treatment*after

**** discontinuity *****
forvalues disc=44/53 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}




****************************************** regression specifications ************************************************

*create weight variable
gen wij=.


*******************
* define controls *
*******************

global controls1 ""



******************************
* set alternative bandwidths *
******************************

global bandwidths "180"


**************************
* specify relevant discs *
**************************

global disc " disc_45 disc_46 disc_47 disc_48 disc_49 disc_50 disc_51 disc_52"



*set instrument
global instrument "after_treatment"

*************************************************** Table 6 ***************************************************

*set Table 6 outcomes
global outcomes "mort_rate" 

*set Table 6 file name
global file "Table6_mort_rate" 

*create outreg file
xi: reg mort_rate, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace

preserve

****************************
*** Panel A: full sample ***
****************************

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	
	
	ts2sls mort_rate (years_schooling=$instrument) after $trend $disc   if abs(day1+0.5)<180 , group(group)
	outreg2 using $file, nocons keep(years_schooling) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

****************************
*** Panel B: 7-day donut ***
****************************

drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
    ts2sls mort_rate (years_schooling=$instrument) after $trend $disc   if abs(day1+0.5)<180 , group(group)
	outreg2 using $file, nocons keep(years_schooling) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}


*****************************
*** Panel C: 14-day donut ***
*****************************

drop if (day1>=-14 & day1<=-1) | (day1>=0 & day1<=13) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
    ts2sls mort_rate (years_schooling=$instrument) after $trend $disc   if abs(day1+0.5)<180 , group(group)
	outreg2 using $file, nocons keep(years_schooling) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

restore

erase "$file.txt"
