clear all
use "short_census92_JHR_reg.dta"


**************************
* define dummy variables *
**************************

**** ethnicity ***
forvalues ethnic=1/4 {
   quietly gen byte ethnic_`ethnic'=0 if ethnic!=.
   quietly replace ethnic_`ethnic'=1 if ethnic==`ethnic'
}


**** discontinuity *****
forvalues disc=44/53 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}



****************************************** collapse data ************************************************

******************
* define density *
******************

gen byte ones=1
bys day1 disc: egen freq=total(ones)
bys disc: egen denom=total(ones)
gen density=freq/denom
replace density=density*100


**********************
* collapse full data *
**********************

collapse density s_years_schooling s_primary years_schooling primary_none lower_sec upper_sec uni employed active children skill1 female ethnic_1 ethnic_2 ethnic_3 ethnic_4 urban buc disc_* after treatment after_treatment day1_* day2* day3* (count) n=ones, by(day1 disc)


****************************************** regression specifications ************************************************

*create weight variable
gen wij=.


*******************
* define controls *
*******************

global controls1 "female ethnic_* region_*"
global controls1 ""


**************************
* specify relevant discs *
**************************

global disc "disc_44 disc_45 disc_46 disc_47 disc_48 disc_49 disc_50 disc_51 disc_52 disc_53"



*****************************
* set trends and bandwidths *
*****************************

*set bandwidth
global bw=180

*specify trend and after
global trend "day1 day1_after day1_treatment day1_treatment_after" 
global after="after after_treatment"



*************************************************** Table 2 ***************************************************

*set Table 2 outcomes
global outcomes "years_schooling primary_none lower_sec upper_sec uni" 

*set Table 2 file name
global file "Table2_educ" 

*create outreg file
xi: reg years_schooling, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace

preserve

****************************
*** Panel A: full sample ***
****************************

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

****************************
*** Panel B: 7-day donut ***
****************************

drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}


*****************************
*** Panel C: 14-day donut ***
*****************************

drop if (day1>=-14 & day1<=-1) | (day1>=0 & day1<=13) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

restore

erase "$file.txt"


*************************************************** Table 3 ***************************************************

*set Table 3 outcomes
global outcomes "employed skill1 children s_years_schooling"

*set Table 3 file name
global file "Table3_socio_economic" 

*create outreg file
xi: reg years_schooling, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace

preserve

****************************
*** Panel A: full sample ***
****************************

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

****************************
*** Panel B: 7-day donut ***
****************************

drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}


*****************************
*** Panel C: 14-day donut ***
*****************************

drop if (day1>=-14 & day1<=-1) | (day1>=0 & day1<=13) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

restore

erase "$file.txt"





*************************************************** Appendix Table 1 ***************************************************

*set Appendix Table 1 outcomes
global outcomes "density female ethnic_1 ethnic_2 ethnic_3 ethnic_4 buc "

*set Appendix Table 1 file name
global file "AppTable1_checks" 

*create outreg file
xi: reg years_schooling, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace

preserve

****************************
*** Panel A: full sample ***
****************************

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

****************************
*** Panel B: 7-day donut ***
****************************

drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}


*****************************
*** Panel C: 14-day donut ***
*****************************

drop if (day1>=-14 & day1<=-1) | (day1>=0 & day1<=13) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

restore

erase "$file.txt"




*************************************************** Appendix Table 2 ***************************************************

*set Appendix Table 2 outcomes
global outcomes "employed skill1 children s_years_schooling"

*set Appendix Table 2 file name
global file "AppTable2_iv_socio_economic" 

*create outreg file
xi: reg years_schooling, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace

*set instrument
global instrument "after_treatment"


preserve

****************************
*** Panel A: full sample ***
****************************

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	ivreg2 `var' (years_schooling=$instrument) after $trend $disc [pw=wij]  if abs(day1+0.5)<=$bw, robust 
	outreg2 using $file, nocons keep(years_schooling) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

****************************
*** Panel B: 7-day donut ***
****************************

drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	ivreg2 `var' (years_schooling=$instrument) after $trend $disc [pw=wij]  if abs(day1+0.5)<=$bw, robust 
	outreg2 using $file, nocons keep(years_schooling) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}


*****************************
*** Panel C: 14-day donut ***
*****************************

drop if (day1>=-14 & day1<=-1) | (day1>=0 & day1<=13) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	ivreg2 `var' (years_schooling=$instrument) after $trend $disc [pw=wij]  if abs(day1+0.5)<=$bw, robust 
	outreg2 using $file, nocons keep(years_schooling) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

restore

erase "$file.txt"




*************************************************** Appendix Table 4 ***************************************************


**************************************
*** restrict to 7-day donut sample ***
**************************************

drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 


*set Appendix Table 4 outcomes
global outcomes "years_schooling density"

*set Appendix Table 4 file name
global file "AppTable4_parametric" 


*create outreg file
xi: reg years_schooling, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace



******************************
*** Regression 7-day donut ***
******************************

foreach var of varlist $outcomes {
	foreach trend in "day1 day1_treatment day1_after day1_treatment_after" "day1 day1_treatment day2 day2_treatment day1_after day1_treatment_after day2_after day2_treatment_after" "day1 day1_treatment day2 day2_treatment day3 day3_treatment day1_after day1_treatment_after day2_after day2_treatment_after day3_after day3_treatment_after" {	
		xi: reg `var' $after `trend' $disc $controls1, robust 
		outreg2 using $file, nocons keep(after after_treatment) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
	}
}


erase "$file.txt"



*************************************************** Estimates for Appendix Figure 6 ***************************************************

**************************************
*** restrict to 7-day donut sample ***
**************************************

drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 



******************************
* set alternative bandwidths *
******************************

global bandwidths "180(10)30"

*specify trend and after
global trend "day1 day1_after day1_treatment day1_treatment_after" 
global after="after after_treatment"


********************************
* years of schooling estimates *
********************************

*set file name
global file "AppFigure6_years_schooling" 

*set variable
global var "years_schooling"

*create outreg file
xi: reg years_schooling, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace


*reset weights
replace wij=.

*loop across alternative bandwidths
foreach bw of numlist $bandwidths {
	quietly replace wij = 1 - abs((day1+0.5)/`bw') 
	quietly replace wij = 0 if abs((day1+0.5)/`bw') >= 1 
	xi: reg $var $after $trend $disc $controls1 [iw=wij]  if abs(day1+0.5)<=`bw' , robust 
	outreg2 using $file, nocons keep($after) stats(coef ci_low ci_high) dec(5) noaster noparen excel slow(20000) append
}


erase "$file.txt"


*********************
* density estimates *
*********************

*set file name
global file "AppFigure6_density" 

*set variable
global var "density"

*create outreg file
xi: reg $var, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace


*reset weights
replace wij=.

*loop across alternative bandwidths
foreach bw of numlist $bandwidths {
	quietly replace wij = 1 - abs((day1+0.5)/`bw') 
	quietly replace wij = 0 if abs((day1+0.5)/`bw') >= 1 
	xi: reg $var $after $trend $disc $controls1 [iw=wij]  if abs(day1+0.5)<=`bw' , robust 
	outreg2 using $file, nocons keep($after) stats(coef ci_low ci_high) dec(5) noaster noparen excel slow(20000) append
}


erase "$file.txt"




*************************************************** Appendix Table 5 ***************************************************


use "short_census92_JHR_reg.dta", clear


**************************************
*** restrict to 7-day donut sample ***
**************************************

drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 


***************************
*** Re-define variables ***
***************************

*create weight variable
gen wij=.

* redefine disc dummies
forvalues disc=44/53 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}



*set Appendix Table 5 outcomes
global outcomes "years_schooling primary_none lower_sec upper_sec uni employed skill1 children s_years_schooling"

*set Appendix Table 5 file name
global file "AppTable4_uncollapsed" 


*create outreg file
xi: reg years_schooling, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace



foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

erase "$file.txt"
