
clear all


use short_census92_JHR.dta, replace


**************
* pre-setup  *
**************

quietly gen byte bmonth=birthm
quietly gen int bdate=birthd if birthd>=1 & birthd<=31


*adjust byear variable
gen byear=birthy+1000

*leap years*
gen byte leap=((mod(byear,4) == 0 & mod(byear,100) != 0) | mod(byear,400) == 0)


*drop 31st date of months with 30 days
drop if bmonth==4 & bdate==31
drop if bmonth==6 & bdate==31
drop if bmonth==9 & bdate==31
drop if bmonth==11 & bdate==31
drop if bmonth==2 & (bdate==30 | bdate==31) 
drop if bmonth==2 & leap==0 & bdate==29


*keep actual month and day of birth*
quietly gen int bday=.
quietly replace bday=0+bdate if bmonth==1 & leap==1
quietly replace bday=31+bdate if bmonth==2 & leap==1
quietly replace bday=60+bdate if bmonth==3 & leap==1
quietly replace bday=91+bdate if bmonth==4 & leap==1
quietly replace bday=121+bdate if bmonth==5 & leap==1
quietly replace bday=152+bdate if bmonth==6 & leap==1
quietly replace bday=182+bdate if bmonth==7 & leap==1
quietly replace bday=213+bdate if bmonth==8 & leap==1
quietly replace bday=244+bdate if bmonth==9 & leap==1
quietly replace bday=274+bdate if bmonth==10 & leap==1
quietly replace bday=305+bdate if bmonth==11 & leap==1
quietly replace bday=335+bdate if bmonth==12 & leap==1

quietly replace bday=0+bdate if bmonth==1 & leap==0
quietly replace bday=31+bdate if bmonth==2 & leap==0
quietly replace bday=59+bdate if bmonth==3 & leap==0
quietly replace bday=90+bdate if bmonth==4 & leap==0
quietly replace bday=120+bdate if bmonth==5 & leap==0
quietly replace bday=151+bdate if bmonth==6 & leap==0
quietly replace bday=181+bdate if bmonth==7 & leap==0
quietly replace bday=212+bdate if bmonth==8 & leap==0
quietly replace bday=243+bdate if bmonth==9 & leap==0
quietly replace bday=273+bdate if bmonth==10 & leap==0
quietly replace bday=304+bdate if bmonth==11 & leap==0
quietly replace bday=334+bdate if bmonth==12 & leap==0

gen int day1=bday if bday<=180
replace day1=bday-365 if bday>185 & leap==0
replace day1=bday-366 if bday>186 & leap==1


**** define day
gen day=byear*1000+bday


**** redfine day1 so cutoff is at 0 (not 1)
replace day1=day1-1


gen int month1=bmonth if bmonth<=6
replace month1=bmonth-12 if bmonth>6


**** define after
gen byte after=(day1>=0)



gen int disc=.

replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 

***************************************** setup ************************************************


************************************
* define treatment discontinuities *
************************************
gen byte treatment=.
*main treatment years
replace treatment=1 if (disc>=44 & disc<=49)
*main control years
replace treatment=0 if (disc>=50 & disc<=52)

*********************************************
*define after*treatment 
gen byte after_treatment=after*treatment

*define separate indicator for control years
gen byte control=1-treatment

*************************************************
*****keep treatment and control cohorts only*****
*************************************************

keep if treatment==1 | treatment==0


***** day trends
gen day2=day1*day1
gen day3=day1*day1*day1
gen day1_after=day1*after
gen day2_after=day2*after
gen day3_after=day3*after

gen day1_treatment=day1*treatment
gen day2_treatment=day2*treatment
gen day3_treatment=day3*treatment

gen day1_treatment_after=day1*treatment*after
gen day2_treatment_after=day2*treatment*after
gen day3_treatment_after=day3*treatment*after

 
 
******************************
* define additional outcomes *
******************************

/* sex */
quietly gen byte female=0 if P08==1
quietly replace female=1 if P08==2
quietly gen byte male=0 if P08==2
quietly replace male=1 if P08==1

/* age */
rename virsta age

/*citizenship - keep only romanians*/
tab P14
keep if P14==10

/*COUNTY*/
/*county of residence*/
gen jud_dom=int(nrmapa/10000)

/*county of birth*/
gen county_birth=jud_dom if P101==90
replace county_birth=P101 if P101!=90
*drop those born abroad
drop if county_birth>50

*dummy if born in Bucharest*
gen byte buc=(county_birth>=41 & county_birth<=47)

/*URBAN*/
/*place of residence - urban area*/
gen urban_dom=mediu==1

/*place of birth - urban area: only 34% born in urban areas*/
gen urban=(urban_dom==1&P101==90)
replace urban=1 if P101!=90&P102==1

/*born in rural and living in urban*/
gen urban_migrant=urban==0&urban_dom==1

*********


/* ethnic group */
quietly gen byte ethnic=.
quietly replace ethnic=1 if P15==10
quietly replace ethnic=2 if P15==11
quietly replace ethnic=3 if P15==12
quietly replace ethnic=4 if P15>12
/* 1-romanian, 2-hungarian, 3-roma, 4-other */


/* no children born alive - only for women*/
quietly gen byte children=P13 if P13>0&P13<99
replace children=. if female==0
*** set children=0 for women with missing values
replace children=0 if children==. & female==1

*** define any children
gen byte anychild=(children>0) if children>=0 & children!=.



/*************************/
/* educational variables */
/*************************/
gen edlevel=P181
replace edlevel=. if edlevel==99

/* specific categories */

quietly gen byte none=(edlevel>=96 & edlevel<=98) if edlevel!=.
quietly gen byte primary=(edlevel>=94 & edlevel<=95) if edlevel!=.
quietly gen byte gym=(edlevel>=91 & edlevel<=93) if edlevel!=.
quietly gen byte gen9_10=(edlevel==90) if edlevel!=.
*vocational and apprenticeship education  - technical vocational schools,...*
quietly gen byte voc=(edlevel>=81 & edlevel<=89) if edlevel!=.
*high school education: theoretical high school 62-65; vocational high_schools: 66-80; include also 90 which is grade 9-10*
quietly gen byte gen9_12=(edlevel==90 | (edlevel>=66 & edlevel<=80) | (edlevel>=62 & edlevel<=65)) if edlevel!=.
*same as gen9_12 but no edlevel=90*
quietly gen byte gen11_12=(edlevel>=66 & edlevel<=80) | (edlevel>=62 & edlevel<=65) if edlevel!=.
*post high school*
quietly gen byte postsec=(edlevel>=50 & edlevel<=61) if edlevel!=.
*NOTE: in my files secondary education goes from 50-93, i.e. includes also gymnasium (gym) and postsec* 
quietly gen byte secondary=((edlevel==90 | (edlevel>=66 & edlevel<=80) | (edlevel>=62 & edlevel<=65)) | (edlevel>=81 & edlevel<=89)) if edlevel!=.
*tertiary education: technical, university, etc.*
quietly gen byte uni=(edlevel>=1 & edlevel<=49) if edlevel!=.

***define additional schooling categories
gen byte primary_none=(primary==1 | none==1) if edlevel!=.
gen byte upper_sec=(secondary==1 | postsec==1) if edlevel!=.
gen byte lower_sec=(gym==1) if edlevel!=.

*** define years of schooling
gen years_schooling=.
replace years_schooling=0 if none==1
replace years_schooling=4  if primary==1
replace years_schooling=8  if gym==1
replace years_schooling=11  if voc==1
replace years_schooling=10  if gen9_10==1
replace years_schooling=12  if gen11_12==1
replace years_schooling=14  if postsec==1
replace years_schooling=17  if uni==1


*spouse's education*
gen sedlevel=s_spouse_edu
quietly gen byte s_none=(sedlevel>=96 & sedlevel<=98) if sedlevel!=.
quietly gen byte s_primary=(sedlevel>=94 & sedlevel<=95) if sedlevel!=.
quietly gen byte s_gym=(sedlevel>=91 & sedlevel<=93) if sedlevel!=.
quietly gen byte s_gen9_10=(sedlevel==90) if sedlevel!=.
*vocational and apprenticeship education  - technical vocational schools,...*
quietly gen byte s_voc=(sedlevel>=81 & sedlevel<=89) if sedlevel!=.
*high school education: theoretical high school 62-65; vocational high_schools: 66-80; include also 90 which is grade 9-10*
quietly gen byte s_gen9_12=(sedlevel==90 | (sedlevel>=66 & sedlevel<=80) | (sedlevel>=62 & sedlevel<=65)) if sedlevel!=.
*same as gen9_12 but no sedlevel=90*
quietly gen byte s_gen11_12=(sedlevel>=66 & sedlevel<=80) | (sedlevel>=62 & sedlevel<=65) if sedlevel!=.
*post high school*
quietly gen byte s_postsec=(sedlevel>=50 & sedlevel<=61) if sedlevel!=.
*NOTE: in my files secondary education goes from 50-93, i.e. includes also gymnasium (gym) and postsec* 
quietly gen byte s_secondary=((sedlevel==90 | (sedlevel>=66 & sedlevel<=80) | (sedlevel>=62 & sedlevel<=65)) | (sedlevel>=81 & sedlevel<=89)) if sedlevel!=.
*tertiary education: technical, university, etc.*
quietly gen byte s_uni=(sedlevel>=1 & sedlevel<=49) if sedlevel!=.

*** define spouse's years of schooling
gen s_years_schooling=.
replace s_years_schooling=0 if s_none==1
replace s_years_schooling=4  if s_primary==1
replace s_years_schooling=8  if s_gym==1
replace s_years_schooling=11  if s_voc==1
replace s_years_schooling=10  if s_gen9_10==1
replace s_years_schooling=12  if s_gen11_12==1
replace s_years_schooling=14  if s_postsec==1
replace s_years_schooling=17  if s_uni==1




/*******************/
/* labor variables */
/*******************/

/* economically active: defined as occupied, unemployed or unemployed looking for the first job*/
quietly gen active=pact==1
/* economically active: defined as occupied, unemployed*/
quietly gen active_alt=(P19==1|P19==2)

**************************************
/***ECONOMIC STATUS January 1992*****/
/* employed (vs. all the others)*/
quietly gen employed=P19==1
/*employed (vs non-employed but active)*/
quietly gen employed_active=P19==1
replace employed_active=. if active==0



/***************/
/* occupations, only for the active individuals*/
/***************/

rename P20 occ
*occ is 990 if P19==3/pers. looking for the first job/999 no answer*
quietly replace occ=. if occ==999|occ==990
*keep only occ only for the employed or unemployed individuals/occ is 0 for hosuewives, retired, etc - not sure how since this q is only asked for the employed or unemployed*
quietly replace occ=. if occ==0

quietly gen int occ1=int(occ/100)
*quietly replace occ=. if occ==1

*NEW SKILL*
quietly gen byte skill1=.
quietly replace skill1=1 if occ1==9
quietly replace skill1=2 if occ1>=5 & occ1<=8
quietly replace skill1=3 if occ1==3|occ1==0|occ1==4
quietly replace skill1=4 if (occ1>=1 & occ1<=2 )
/*1 -very low skill; 4- very high skill*/



compress
drop P*
save "short_census92_JHR_reg.dta", replace

